@@ -1303,20 +1303,25 @@ class CScreen extends CApiService {
 
 		// Adding user shares.
 		if ($options['selectUsers'] !== null && $options['selectUsers'] != API_OUTPUT_COUNT) {
+			$userids = [];
 			$relation_map = $this->createRelationMap($result, 'screenid', 'userid', 'screen_user');
-			// Get all allowed users.
-			$related_users = API::User()->get([
-				'output' => ['userid'],
-				'userids' => $relation_map->getRelatedIds(),
-				'preservekeys' => true
-			]);
+			$related_ids = $relation_map->getRelatedIds();
 
-			$related_userids = zbx_objectValues($related_users, 'userid');
+			if ($related_ids) {
+				// Get all allowed users.
+				$users = API::User()->get([
+					'output' => ['userid'],
+					'userids' => $related_ids,
+					'preservekeys' => true
+				]);
 
-			if ($related_userids) {
+				$userids = zbx_objectValues($users, 'userid');
+			}
+
+			if ($userids) {
 				$users = API::getApiService()->select('screen_user', [
 					'output' => $this->outputExtend($options['selectUsers'], ['screenid', 'userid']),
-					'filter' => ['screenid' => $screenIds, 'userid' => $related_userids],
+					'filter' => ['screenid' => $screenIds, 'userid' => $userids],
 					'preservekeys' => true
 				]);
 
@@ -1343,20 +1348,25 @@ class CScreen extends CApiService {
 
 		// Adding user group shares.
 		if ($options['selectUserGroups'] !== null && $options['selectUserGroups'] != API_OUTPUT_COUNT) {
+			$groupids = [];
 			$relation_map = $this->createRelationMap($result, 'screenid', 'usrgrpid', 'screen_usrgrp');
-			// Get all allowed groups.
-			$related_groups = API::UserGroup()->get([
-				'output' => ['usrgrpid'],
-				'usrgrpids' => $relation_map->getRelatedIds(),
-				'preservekeys' => true
-			]);
+			$related_ids = $relation_map->getRelatedIds();
 
-			$related_groupids = zbx_objectValues($related_groups, 'usrgrpid');
+			if ($related_ids) {
+				// Get all allowed groups.
+				$groups = API::UserGroup()->get([
+					'output' => ['usrgrpid'],
+					'usrgrpids' => $related_ids,
+					'preservekeys' => true
+				]);
 
-			if ($related_groupids) {
+				$groupids = zbx_objectValues($groups, 'usrgrpid');
+			}
+
+			if ($groupids) {
 				$user_groups = API::getApiService()->select('screen_usrgrp', [
 					'output' => $this->outputExtend($options['selectUserGroups'], ['screenid', 'usrgrpid']),
-					'filter' => ['screenid' => $screenIds, 'usrgrpid' => $related_groupids],
+					'filter' => ['screenid' => $screenIds, 'usrgrpid' => $groupids],
 					'preservekeys' => true
 				]);
 
