@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -35,7 +35,6 @@ class CUserGroup extends CApiService {
 	 * @param array  $options['usrgrpids']
 	 * @param array  $options['userids']
 	 * @param bool   $options['status']
-	 * @param bool   $options['with_gui_access']
 	 * @param bool   $options['selectUsers']
 	 * @param int    $options['count']
 	 * @param string $options['pattern']
@@ -59,7 +58,6 @@ class CUserGroup extends CApiService {
 			'usrgrpids'					=> null,
 			'userids'					=> null,
 			'status'					=> null,
-			'with_gui_access'			=> null,
 			// filter
 			'filter'					=> null,
 			'search'					=> null,
@@ -117,11 +115,6 @@ class CUserGroup extends CApiService {
 			$sqlParts['where'][] = 'g.users_status='.zbx_dbstr($options['status']);
 		}
 
-		// with_gui_access
-		if (!is_null($options['with_gui_access'])) {
-			$sqlParts['where'][] = 'g.gui_access='.GROUP_GUI_ACCESS_ENABLED;
-		}
-
 		// filter
 		if (is_array($options['filter'])) {
 			$this->dbFilter('usrgrp g', $options, $sqlParts);
@@ -530,6 +523,7 @@ class CUserGroup extends CApiService {
 
 		foreach ($usrgrps as $usrgrp) {
 			if (self::userGroupDisabled($usrgrp, $method, $db_usrgrps)
+					&& array_key_exists('userids', $usrgrp)
 					&& uint_in_array(self::$userData['userid'], $usrgrp['userids'])) {
 				self::exception(ZBX_API_ERROR_PARAMETERS,
 					_('User cannot add himself to a disabled group or a group with disabled GUI access.')
@@ -930,57 +924,65 @@ class CUserGroup extends CApiService {
 
 		// adding users
 		if ($options['selectUsers'] !== null && $options['selectUsers'] != API_OUTPUT_COUNT) {
+			$dbUsers = [];
 			$relationMap = $this->createRelationMap($result, 'usrgrpid', 'userid', 'users_groups');
+			$related_ids = $relationMap->getRelatedIds();
 
-			$get_access = ($this->outputIsRequested('gui_access', $options['selectUsers'])
-				|| $this->outputIsRequested('debug_mode', $options['selectUsers'])
-				|| $this->outputIsRequested('users_status', $options['selectUsers'])) ? true : null;
+			if ($related_ids) {
+				$get_access = ($this->outputIsRequested('gui_access', $options['selectUsers'])
+					|| $this->outputIsRequested('debug_mode', $options['selectUsers'])
+					|| $this->outputIsRequested('users_status', $options['selectUsers'])) ? true : null;
 
-			$dbUsers = API::User()->get([
-				'output' => $options['selectUsers'],
-				'userids' => $relationMap->getRelatedIds(),
-				'getAccess' => $get_access,
-				'preservekeys' => true
-			]);
+				$dbUsers = API::User()->get([
+					'output' => $options['selectUsers'],
+					'userids' => $related_ids,
+					'getAccess' => $get_access,
+					'preservekeys' => true
+				]);
+			}
 
 			$result = $relationMap->mapMany($result, $dbUsers, 'users');
 		}
 
 		// adding usergroup rights
 		if ($options['selectRights'] !== null && $options['selectRights'] != API_OUTPUT_COUNT) {
+			$db_rights = [];
 			$relationMap = $this->createRelationMap($result, 'groupid', 'rightid', 'rights');
+			$related_ids = $relationMap->getRelatedIds();
 
-			if (is_array($options['selectRights'])) {
-				$pk_field = $this->pk('rights');
+			if ($related_ids) {
+				if (is_array($options['selectRights'])) {
+					$pk_field = $this->pk('rights');
 
-				$output_fields = [
-					$pk_field => $this->fieldId($pk_field, 'r')
-				];
+					$output_fields = [
+						$pk_field => $this->fieldId($pk_field, 'r')
+					];
 
-				foreach ($options['selectRights'] as $field) {
-					if ($this->hasField($field, 'rights')) {
-						$output_fields[$field] = $this->fieldId($field, 'r');
+					foreach ($options['selectRights'] as $field) {
+						if ($this->hasField($field, 'rights')) {
+							$output_fields[$field] = $this->fieldId($field, 'r');
+						}
 					}
+
+					$output_fields = implode(',', $output_fields);
+				}
+				else {
+					$output_fields = 'r.*';
 				}
 
-				$output_fields = implode(',', $output_fields);
-			}
-			else {
-				$output_fields = 'r.*';
-			}
+				$db_rights = DBfetchArray(DBselect(
+					'SELECT '.$output_fields.
+					' FROM rights r'.
+					' WHERE '.dbConditionInt('r.rightid', $related_ids).
+						((self::$userData['type'] == USER_TYPE_SUPER_ADMIN) ? '' : ' AND r.permission>'.PERM_DENY)
+				));
+				$db_rights = zbx_toHash($db_rights, 'rightid');
 
-			$db_rights = DBfetchArray(DBselect(
-				'SELECT '.$output_fields.
-				' FROM rights r'.
-				' WHERE '.dbConditionInt('r.rightid', $relationMap->getRelatedIds()).
-					((self::$userData['type'] == USER_TYPE_SUPER_ADMIN) ? '' : ' AND r.permission>'.PERM_DENY)
-			));
-			$db_rights = zbx_toHash($db_rights, 'rightid');
-
-			foreach ($db_rights as &$db_right) {
-				unset($db_right['rightid'], $db_right['groupid']);
+				foreach ($db_rights as &$db_right) {
+					unset($db_right['rightid'], $db_right['groupid']);
+				}
+				unset($db_right);
 			}
-			unset($db_right);
 
 			$result = $relationMap->mapMany($result, $db_rights, 'rights');
 		}
